==> react-annotate-1.8.16.tgz: package/ClassSelectionMenu/index.js <==
import Box from "@material-ui/core/Box";
import * as muiColors from "@material-ui/core/colors";
import { styled } from "@material-ui/core/styles";
import BallotIcon from "@material-ui/icons/Ballot";
import classnames from "classnames";
import capitalize from "lodash/capitalize";
import React, { useEffect } from "react";
import colors from "../colors";
import SidebarBoxContainer from "../SidebarBoxContainer";
var LabelContainer = styled("div")({
  display: "flex",
  paddingTop: 4,
  paddingBottom: 4,
  paddingLeft: 16,
  paddingRight: 16,
  alignItems: "center",
  cursor: "pointer",
  opacity: 0.7,
  backgroundColor: "#fff",
  "&:hover": {
    opacity: 1
  },
  "&.selected": {
    opacity: 1,
    fontWeight: "bold"
  }
});
var Circle = styled("div")({
  width: 12,
  height: 12,
  borderRadius: 12,
  marginRight: 8
});
var Label = styled("div")({
  fontSize: 11
});
var DashSep = styled("div")({
  flexGrow: 1,
  borderBottom: "2px dotted ".concat(muiColors.grey[300]),
  marginLeft: 8,
  marginRight: 8
});
var Number = styled("div")({
  fontSize: 11,
  textAlign: "center",
  minWidth: 14,
  paddingTop: 2,
  paddingBottom: 2,
  fontWeight: "bold",
  color: muiColors.grey[700]
});
export var ClassSelectionMenu = function ClassSelectionMenu(_ref) {
  var selectedCls = _ref.selectedCls,
      regionClsList = _ref.regionClsList,
      onSelectCls = _ref.onSelectCls;
  useEffect(function () {
    var keyMapping = {};

    var _loop = function _loop(i) {
      keyMapping[i + 1] = function () {
        return onSelectCls(regionClsList[i]);
      };
    };

    for (var i = 0; i < 9 && i < regionClsList.length; i++) {
      _loop(i);
    }

    var onKeyDown = function onKeyDown(e) {
      if (keyMapping[e.key]) {
        keyMapping[e.key]();
        e.preventDefault();
        e.stopPropagation();
      }
    };

    window.addEventListener("keydown", onKeyDown);
    return function () {
      return window.removeEventListener("keydown", onKeyDown);
    };
  }, [regionClsList, selectedCls]);
  return React.createElement(SidebarBoxContainer, {
    title: "Tags",
    subTitle: "",
    icon: React.createElement(BallotIcon, {
      style: {
        color: muiColors.grey[700]
      }
    }),
    expandedByDefault: true
  }, regionClsList.map(function (label, index) {
    return React.createElement(LabelContainer, {
      className: classnames({
        selected: label === selectedCls
      }),
      onClick: function onClick() {
        return onSelectCls(label);
      },
      key: index
    }, React.createElement(Circle, {
      style: {
        backgroundColor: colors[index % colors.length]
      }
    }), React.createElement(Label, {
      className: classnames({
        selected: label === selectedCls
      })
    }, capitalize(label)), React.createElement(DashSep, null), React.createElement(Number, {
      className: classnames({
        selected: label === selectedCls
      })
    }));
  }), React.createElement(Box, {
    pb: 2
  }));
};
export default ClassSelectionMenu;

==> react-annotate-1.8.19.tgz: package/ClassSelectionMenu/index.js <==
import Box from "@material-ui/core/Box";
import * as muiColors from "@material-ui/core/colors";
import { styled } from "@material-ui/core/styles";
import BallotIcon from "@material-ui/icons/Ballot";
import classnames from "classnames";
import capitalize from "lodash/capitalize";
import React, { useEffect } from "react";
import colors from "../colors";
import SidebarBoxContainer from "../SidebarBoxContainer";
var LabelContainer = styled("div")({
  display: "flex",
  paddingTop: 4,
  paddingBottom: 4,
  paddingLeft: 16,
  paddingRight: 16,
  alignItems: "center",
  cursor: "pointer",
  opacity: 0.7,
  backgroundColor: "var(--header-background-color)",
  "&:hover": {
    opacity: 1
  },
  "&.selected": {
    opacity: 1,
    fontWeight: "bold",
    animation: "none !important"
  },
  "&.bounty": {
    color: "white",
    background: "purple",
    borderRadius: 30
  },
  "&.bountyNotFulfilled": {
    animation: "glowing 1300ms infinite",
    background: "purple"
  }
});
var Circle = styled("div")({
  width: 12,
  height: 12,
  borderRadius: 12,
  marginRight: 8
});
var Label = styled("div")({
  fontSize: 11
});
var DashSep = styled("div")({
  flexGrow: 1,
  borderBottom: "2px dotted ".concat(muiColors.grey[300]),
  marginLeft: 8,
  marginRight: 8
});
var Number = styled("div")({
  fontSize: 11,
  textAlign: "center",
  minWidth: 14,
  paddingTop: 2,
  paddingBottom: 2,
  fontWeight: "bold",
  color: muiColors.grey[700]
});
export var ClassSelectionMenu = function ClassSelectionMenu(_ref) {
  var regions = _ref.regions,
      selectedCls = _ref.selectedCls,
      regionClsList = _ref.regionClsList,
      onSelectCls = _ref.onSelectCls,
      checkRegionsForBounty = _ref.checkRegionsForBounty;
  useEffect(function () {
    var keyMapping = {};

    var _loop = function _loop(i) {
      keyMapping[i + 1] = function () {
        return onSelectCls(regionClsList[i]);
      };
    };

    for (var i = 0; i < 9 && i < regionClsList.length; i++) {
      _loop(i);
    }

    var onKeyDown = function onKeyDown(e) {
      if (keyMapping[e.key]) {
        keyMapping[e.key]();
        e.preventDefault();
        e.stopPropagation();
      }
    };

    window.addEventListener("keydown", onKeyDown);
    return function () {
      return window.removeEventListener("keydown", onKeyDown);
    };
  }, [regionClsList, selectedCls]);
  return React.createElement(SidebarBoxContainer, {
    title: "Tags",
    subTitle: "",
    icon: React.createElement(BallotIcon, {
      style: {
        color: muiColors.grey[700]
      }
    }),
    expandedByDefault: true
  }, regionClsList.map(function (label, index) {
    return React.createElement(LabelContainer, {
      className: classnames({
        selected: label === selectedCls,
        bounty: label === 'anonymization bounty',
        bountyNotFulfilled: label === 'anonymization bounty' && !checkRegionsForBounty("anonymization bounty", regions)
      }),
      onClick: function onClick() {
        return onSelectCls(label);
      },
      key: index
    }, React.createElement(Circle, {
      style: {
        backgroundColor: colors[index % colors.length]
      }
    }), React.createElement(Label, {
      className: classnames({
        selected: label === selectedCls
      })
    }, capitalize(label)), React.createElement(DashSep, null), React.createElement(Number, {
      className: classnames({
        selected: label === selectedCls
      })
    }));
  }), React.createElement(Box, {
    pb: 2
  }));
};
export default ClassSelectionMenu;
